/**
 * Configuration for a bryntum grid
 */
import { DataGenerator } from '@bryntum/grid';

const gridConfig = {
    minHeight: '20em',

    selectionMode: {
        row: true,
        checkbox: true
    },

    columnLines: false,
    data: DataGenerator.generateData(50),
    columns: [
        { type: 'rownumber' },
        {
            text: 'Template',
            field: 'name',
            flex: 1,
            type: 'template',
            template: data => `Hi ${data.record.data.name}!`
        },
        {
            text: 'Percent',
            field: 'percent',
            flex: 1,
            type: 'percent'
        },
        {
            text: 'Widget',
            field: 'age',
            width: 100,
            type: 'widget',
            widgets: [
                {
                    type: 'button',
                    tooltip: 'Add',
                    icon: 'b-fa b-fa-plus',
                    cls: 'b-blue b-raised',
                    onAction: ({ source: btn }) => {
                        btn.cellInfo.record.age++;
                    }
                }
            ]
        },
        {
            text: 'Date',
            field: 'start',
            flex: 1,
            type: 'date',
            format: 'MMMM Do YYYY'
        },
        {
            text: 'Time',
            field: 'time',
            flex: 1,
            type: 'time',
            format: 'LT'
        },
        {
            text: 'Link',
            field: 'name',
            type: 'template',
            editor: false,
            template:  () =>
                `<a href="//www.bryntum.com" target="_blank">Click me</a>`
        },
        {
            text: 'Custom',
            type: 'color'
        },
        {
            type: 'rating',
            text: 'Rating',
            cellCls: 'satisfaction',
            max: 5,
            field: 'rating'
        },
        {
            type: 'action',
            field: 'rating',
            actions: [
                {
                    cls: 'b-fa b-fa-minus-circle',
                    tooltip: 'Decrease rating',
                    onClick: ({ record }) => {
                        if (record.rating > 1) {
                            record.rating--;
                        }
                    }
                },
                {
                    cls: 'b-fa b-fa-plus-circle',
                    tooltip: 'Increase rating',
                    onClick: ({ record }) => {
                        if (record.rating < 5) {
                            record.rating++;
                        }
                    }
                }
            ]
        }
    ]
};

export { gridConfig };
